#
# spec file for package eclipse-swt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global archs_32bit s390 %{arm} %{ix86}
%global major_version   4
%ifarch %{archs_32bit}
%global minor_version   9
%global other_minor_version 29
%else
%global minor_version   29
%global other_minor_version 9
%endif
%global tag R%{major_version}_%{minor_version}
%global other_tag R%{major_version}_%{other_minor_version}
%global swtsrcdir       bundles/org.eclipse.swt
Name:           eclipse-swt
Version:        %{major_version}.%{minor_version}
Release:        1.0.2.1.sr20250601
Summary:        Eclipse SWT: The Standard Widget Toolkit for GTK+
License:        EPL-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/eclipse-platform/eclipse.platform.swt
Source0:        https://codeload.github.com/eclipse-platform/eclipse.platform.swt/tar.gz/refs/tags/%{tag}#/eclipse.platform.swt-%{tag}.tar.gz
Source1:        classpath.xls
Source2:        https://github.com/eclipse-platform/eclipse.platform.swt/raw/refs/tags/R4_29/LICENSE
Source3:        https://github.com/eclipse-platform/eclipse.platform.swt/raw/refs/tags/R4_29/NOTICE
# These two are the other sources, listed here to appease bots
Source100:      https://codeload.github.com/eclipse-platform/eclipse.platform.swt/tar.gz/refs/tags/%{other_tag}#/eclipse.platform.swt-%{other_tag}.tar.gz
Source101:      eclipse-swt-avoid-javascript-at-build-%{major_version}_%{other_minor_version}.patch
Source102:      eclipse-swt-gcc15-%{major_version}_%{other_minor_version}.patch
Patch0:         eclipse-swt-avoid-javascript-at-build-%{major_version}_%{minor_version}.patch
Patch1:         eclipse-swt-rm-eclipse-tasks-and-customize-build.patch
Patch2:         eclipse-swt-fedora-build-native.patch
Patch3:         eclipse-gcc10.patch
Patch4:         eclipse-swt-gcc15-%{major_version}_%{minor_version}.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  java-devel
BuildRequires:  javapackages-local
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  webkit2gtk3-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(xt)
Obsoletes:      %{name}-bootstrap

%description
SWT is an open source widget toolkit for Java designed to provide
efficient, portable access to the user-interface facilities of the
operating systems on which it is implemented.

%package javadoc
Summary:        Javadocs for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n eclipse.platform.swt-%{tag}
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1
%ifarch %{archs_32bit}
%patch -P 3 -p2
%endif
%patch -P 4 -p1
mkdir -p %{swtsrcdir}/tasks
cp %{SOURCE1} %{swtsrcdir}/tasks
cp %{SOURCE2} %{SOURCE3} .

cp %{swtsrcdir}/Eclipse\ SWT/common/library/* %{swtsrcdir}/Eclipse\ SWT\ PI/gtk/library/
cp %{swtsrcdir}/Eclipse\ SWT/common/version.txt %{swtsrcdir}/
cp %{swtsrcdir}/Eclipse\ SWT\ PI/{common,cairo}/library/* %{swtsrcdir}/Eclipse\ SWT\ PI/gtk/library/
cp %{swtsrcdir}/Eclipse\ SWT\ OpenGL/glx/library/* %{swtsrcdir}/Eclipse\ SWT\ PI/gtk/library/
cp %{swtsrcdir}/Eclipse\ SWT\ WebKit/gtk/library/* %{swtsrcdir}/Eclipse\ SWT\ PI/gtk/library/
cp %{swtsrcdir}/Eclipse\ SWT\ AWT/gtk/library/* %{swtsrcdir}/Eclipse\ SWT\ PI/gtk/library/

%build

cd %{swtsrcdir}

# Build native part
export SWT_LIB_DEBUG=1
export CFLAGS="%{optflags} -fPIC"
export LFLAGS="${RPM_LD_FLAGS}"
ant -f buildSWT.xml build_local \
    -Dant.build.javac.source=8 -Dant.build.javac.target=8 \
    -Dbuild_dir=Eclipse\ SWT\ PI/gtk/library \
    -Dtargets="-gtk3 install" -Dclean= -Dcflags="%{optflags}" \
    -Dlflags="${RPM_LD_FLAGS}" -Dswt.arch=%{_arch}

# Build Java part
ant -f buildSWT.xml check_compilation_all_platforms \
    -Dant.build.javac.source=8 -Dant.build.javac.target=8 \
    -Drepo.src=../../

# Build Jar file
ant -f build.xml \
    -Dant.build.javac.source=8 -Dant.build.javac.target=8

%install
# Install Maven metadata for SWT
# jar
JAR=%{swtsrcdir}/org.eclipse.swt_*.jar
VER=$(echo $JAR | sed -e "s/.*_\(.*\)\.jar/\1/")
install -dm 0755 %{buildroot}%{_jnidir}/eclipse
install -pm 0644 %{swtsrcdir}/org.eclipse.swt_*.jar %{buildroot}%{_jnidir}/swt.jar
ln -s -f ../swt.jar %{buildroot}%{_jnidir}/eclipse/swt.jar
%add_maven_depmap "org.eclipse.swt:org.eclipse.swt:jar:$VER" swt.jar -a "org.eclipse.swt:swt"
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}
cp -r %{swtsrcdir}/docs/api %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}

# fix so permissions
find %{swtsrcdir}/*.so -name *.so -exec chmod a+x {} \;

install -d 755 %{buildroot}/%{_libdir}/%{name}
cp -a %{swtsrcdir}/*.so %{buildroot}/%{_libdir}/%{name}

%files -f .mfiles
%{_libdir}/%{name}
%{_jnidir}/eclipse
%license LICENSE NOTICE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE NOTICE

%changelog
* Wed Jun 18 2025 Fridrich Strba <fstrba@suse.com>
- Extend the architectures to build to all the 64-bit ones
  * use the 4.29 version for them
- Added patches:
  * eclipse-swt-avoid-javascript-at-build-4_29.patch
  * eclipse-swt-gcc15-4_29.patch
    + the 4.29 version of the 4.9 patches
* Mon Jun 16 2025 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * eclipse-swt-gcc15-4_9.patch
    + fix build with gcc15
* Thu Jun 12 2025 Fridrich Strba <fstrba@suse.com>
- Clean the spec file and avoid fetching and modifying sources by
  script. It is now possible to download from github tarballs of
  submodules without having to fetch all eclipse sources.
- Removed patches:
  * eclipse-arm32.patch
  * eclipse-is64.patch
  * eclipse-jintlong.patch
  * eclipse-ppc64.patch
  * eclipse-secondary-arches.patch
  * eclipse-swt-optflags.patch
    + not needed after the cleanup
- Added patches:
  * eclipse-swt-fedora-build-native.patch
    + patch from Fedora to avoid hardcoding of CFLAGS for the native
    Build
  * eclipse-swt-rm-eclipse-tasks-and-customize-build.patch
    + remove from build the eclipse tasks that we cannot run and
    that we don't need
  * eclipse-swt-avoid-javascript-at-build-4_9.patch
    + avoid using javascript to determine versions that we don't
    need to know
* Fri Mar 28 2025 Fridrich Strba <fstrba@suse.com>
- Do not require xmvn-tools for building
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Jun 18 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * eclipse-jintlong.patch
    + fix several incoherences preventing correct JNI calls on x86
* Thu May 26 2022 Fridrich Strba <fstrba@suse.com>
- Build also the gtk3 support of webkit including the webkit2
  extensions
- Modified patch:
  * eclipse-is64.patch
    + run actually replace64 if the *value* of is64 is false
* Fri Apr 22 2022 Fridrich Strba <fstrba@suse.com>
- Add a fake provide osgi(org.eclipse.swt) to make packages that
  require it installable. But, since on the architectures where this
  package is present, full eclipse does not exist, nothing will ever
  try to resolve the bundle itself.
* Tue Nov 16 2021 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * eclipse-is64.patch
    + do not let is64 undefined when it is false
* Thu Apr  9 2020 Fridrich Strba <fstrba@suse.com>
- Build eclipse-swt for architectures where eclipse itself is not
  supported any more
- This is the last version that was supported on 32-bit
  architectures
* Sun Oct 22 2017 fstrba@suse.com
- Declare the right architecture in manifest file
  * Fixes problems reported in bsc#1062807
* Wed Oct 18 2017 stefan.bruens@rwth-aachen.de
- Add aarch64.patch, sets JNI64 on aarch64
* Fri Oct  6 2017 fstrba@suse.com
- Build with java source and target 1.6 in order to allow building
  with jdk9
- Added patch:
  * libswt-bootclasspath.patch
    + Don't use bootclasspath; it does not work with java9, since
    no jar files are distributed, and it is not needed for
    java 7 or 8.
- Modified patch:
  * libswt-4.333-libjawt.patch
    + Use elif in order to make the patch shorter and more elegant
* Wed Sep 20 2017 zaitor@opensuse.org
- Drop libwebkit-devel BuildRequires: webkitgtk is deprecated, and
  will be removed from tumbleweed.
* Mon Sep 18 2017 fstrba@suse.com
- Temporarily build against jdk8 until the build is fixed
- Modified patch:
  * libswt-includes.patch
    + Do not explicitely look for gcj includes, since we use the
    includes in JAVA_HOME
- Added patch:
  * libswt-4.333-libjawt.patch
    + Find libjawt correctly also in jdk9
* Wed Jun  8 2016 normand@linux.vnet.ibm.com
- same ppc64le_path_for_jre_1_7_0.patch for suse_version >= 1330
  (so remove version test in spec)
* Fri Aug 28 2015 normand@linux.vnet.ibm.com
-  new patch for ppc64le for suse_version <= 1315
  ppc64le_path_for_jre_1_7_0.patch
* Wed Aug 12 2015 dvaleev@suse.com
- Fix SWT_ARCH on ppc64le (refresh ppc64le.patch)
* Tue Jul  1 2014 tchvatal@suse.com
- Revert back to 4.333 as it broke build of only dependant package
- Removed patches:
  * build.patch
  * jni64.patch
- Added patches:
  * libswt-includes.patch
  * libswt-build.patch
  * libswt-optflags.patch
  * libswt-plugindir.patch
  * ppc64le.patch
* Mon May 19 2014 schwab@suse.de
- Fix bogus arch setting
- jni64.patch: Fix JNI64 setting
- build.patch: Fix AWT_ARCH setting
* Fri May 16 2014 mailaender@opensuse.org
- update to version 4.335 (Eclipse Kepler Service Release 2)
- https://en.opensuse.org/SourceUrls
- only use the upstream provided parametrized ant scripts
- dropped all patches hacking a custom build system
* Tue Jan 14 2014 embar@super.lt
- Fix build for openSUSE Tumbleweed and 11.4
* Tue Jan 14 2014 joerg.lorenzen@ki.tng.de
- update to version 4.333
- remove libswt-version.patch
- add libswt-plugindir.patch
* Thu Jan  2 2014 dvaleev@suse.com
- enable ppc64le build
- add ppc64le.patch
* Wed Oct 17 2012 embar@super.lt
- Fix build for openSUSE Factory
* Fri Sep 21 2012 idonmez@suse.com
- Add explicit glu dependency
* Fri Jun 29 2012 coolo@suse.com
- use use one libgcj to rule them all
* Wed Jun 13 2012 embar@super.lt
- Remove mozilla-xulrunner192 dependency (fix bnc#766485)
* Fri Nov 25 2011 embar@super.lt
- Use libgcj45 for openSUSE 11.4 and older versions
- Fix bnc#732684
* Mon Oct 24 2011 coolo@suse.com
- use gcc46
* Wed Sep 21 2011 cfarrell@suse.com
- license update: Eclipse-1.0
  Use SPDX format (http://www.spdx.org/licenses)
* Fri Jul  1 2011 joerg.lorenzen@ki.tng.de
- update to version 3.735
* Wed May 18 2011 joerg.lorenzen@ki.tng.de
- update to version 3.730
* Thu Mar 17 2011 joerg.lorenzen@ki.tng.de
- update to version 3.724
* Tue Feb  8 2011 joerg.lorenzen@ki.tng.de
- update to version 3.712
* Sat Oct  9 2010 joerg.lorenzen@ki.tng.de
- update to version 3.655
* Wed Sep 15 2010 joerg.lorenzen@ki.tng.de
- Initial package, version 3.650
